reptile_train_one_mode(epimark, label, family, ntree, nodesize)data.frame instance from read_epigenomic_data, which containing
intensity and intensity deviation values of each mark for each DMR
or query region.
factor instance from read_label, containing the label of each
query region. The possible values and their meanings of a label
are: 0 (not enhancer), 1 (enhancer) and NA
(unknwon and will be ignored).
randomForest object or glm object when family
is set to be "Logistic".
A. Liaw and M. Wiener (2002), Classification and Regression by randomForest, R News 2(3), 18--22.
reptile_train